Host

Trait Host 

pub trait Host: Send {
    // Required methods
    fn get_environment(
        &mut self,
    ) -> impl Future<Output = Result<Vec<(String, String)>>> + Send;
    fn get_arguments(
        &mut self,
    ) -> impl Future<Output = Result<Vec<String>>> + Send;
    fn initial_cwd(
        &mut self,
    ) -> impl Future<Output = Result<Option<String>>> + Send;
}

Required Methods

fn get_environment( &mut self, ) -> impl Future<Output = Result<Vec<(String, String)>>> + Send

Get the POSIX-style environment variables.

Each environment variable is provided as a pair of string variable names and string value.

Morally, these are a value import, but until value imports are available in the component model, this import function should return the same values each time it is called.

fn get_arguments(&mut self) -> impl Future<Output = Result<Vec<String>>> + Send

Get the POSIX-style arguments to the program.

fn initial_cwd(&mut self) -> impl Future<Output = Result<Option<String>>> + Send

Return a path that programs should use as their initial current working directory, interpreting . as shorthand for this.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl<_T: Host + ?Sized + Send> Host for &mut _T

Source

fn get_environment( &mut self, ) -> impl Future<Output = Result<Vec<(String, String)>>> + Send

Get the POSIX-style environment variables.

Each environment variable is provided as a pair of string variable names and string value.

Morally, these are a value import, but until value imports are available in the component model, this import function should return the same values each time it is called.

Source

fn get_arguments(&mut self) -> impl Future<Output = Result<Vec<String>>> + Send

Get the POSIX-style arguments to the program.

Source

fn initial_cwd(&mut self) -> impl Future<Output = Result<Option<String>>> + Send

Return a path that programs should use as their initial current working directory, interpreting . as shorthand for this.

Implementors